# Amulet Map Editor

![Build](../../workflows/Build/badge.svg)
![Unittests](../../workflows/Unittests/badge.svg?event=push)
![Stylecheck](../../workflows/Stylecheck/badge.svg?event=push)
[![Documentation Status](https://readthedocs.org/projects/amulet-map-editor/badge)](https://amulet-map-editor.readthedocs.io)

A new Minecraft world editor and converter that supports all versions since Java 1.12 and Bedrock 1.7.

![cover](resource/img/cover.jpg)

## Installing (Currently Windows only)

Purchase and download the installer for your operating system from [amuletmc.com](https://www.amuletmc.com).
Run the installer and follow the instructions.

## Running from Source

**If you are running a compiled build you do NOT need to do this.**

See instructions on [amuletmc.com](https://www.amuletmc.com/installing-from-source)

## Running with Docker (Linux)
The Docker image runs on any Linux distro with Docker support.
To run the Docker image, clone this repository and run `rundocker.sh`.
Compatibility with wayland is done through xwayland for x11 support.

## Legacy builds

Old versions (prior to 0.10.45) can be found on our [releases page](https://github.com/Amulet-Team/Amulet-Map-Editor/releases).

Extract the contained folder to a location on your computer and run `amulet_app.exe`.

## Contributing

For information about contributing to this project, please read the [contribution](contributing.md) file.
